/*
 *   Copyright 2004 The Apache Software Foundation
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package org.apache.ldap.server.jndi;

import javax.naming.NamingException;

/**
 * An event handler that listens to the changes occurs to
 * {@link ContextFactoryService}.
 * 
 * @author The Apache Directory Project
 * @version $Rev: 226451 $, $Date: 2005-07-29 20:54:58 -0400 (Fri, 29 Jul 2005) $
 */
public interface ContextFactoryServiceListener
{
    /**
     * Invoked before starting up {@link ContextFactoryService}.
     */
    void beforeStartup( ContextFactoryService service ) throws NamingException;
    /**
     * Invoked after starting up {@link ContextFactoryService}.
     */
    void afterStartup( ContextFactoryService service ) throws NamingException;
    /**
     * Invoked before shutting down {@link ContextFactoryService}.
     */
    void beforeShutdown( ContextFactoryService service ) throws NamingException;
    /**
     * Invoked after shutting down {@link ContextFactoryService}.
     */
    void afterShutdown( ContextFactoryService service ) throws NamingException;
    /**
     * Invoked before calling {@link ContextFactoryService#sync()}.
     */
    void beforeSync( ContextFactoryService service ) throws NamingException;
    /**
     * Invoked after calling {@link ContextFactoryService#sync()}.
     */
    void afterSync( ContextFactoryService service ) throws NamingException;
}
